@@ -44,30 +44,39 @@ class EnviumError(Exception):
 
 class RedefinedVarError(EnviumError):
     def __init__(self, var_name: str) -> None:
+        self.var_name = var_name
         msg = f'Variable "{var_name}" is redefined'
         super().__init__(msg)
 
 
 class WrongTypeError(EnviumError):
     def __init__(self, var_name: str, type_: Type, got_type: Type) -> None:
+        self.var_name = var_name
+        self.type_ = type_
+        self.got_type = got_type
+
         msg = f'Expected type "{type_.__name__}" for var "{var_name}" got "{got_type}"'
         super().__init__(msg)
 
 
 class NoTypeError(EnviumError):
     def __init__(self, var_name: str) -> None:
+        self.var_name = var_name
         msg = f'Type annotation for var "{var_name}" is missing'
         super().__init__(msg)
 
 
 class NoValueError(EnviumError):
     def __init__(self, var_name: str, type_: Type) -> None:
+        self.var_name = var_name
+        self.type_ = type_
         msg = f'Expected value of type "{type_.__name__}" for var "{var_name}" not None'
         super().__init__(msg)
 
 
 class ComputedVarError(EnviumError):
     def __init__(self, var_name: str, exception: Exception) -> None:
+        self.var_name = var_name
         msg = f'During computing "{var_name}" following error occured: \n{repr(exception)}'
         super().__init__(msg)
 
@@ -103,11 +112,7 @@ class BaseVar(ABC, Generic[VarType]):
         if self._raw:
             return self._name
 
-        ret = (
-            f"{self._parent._fullname}.{self._name}"
-            if self._parent
-            else f"{self._root._name}.{self._name}"
-        )
+        ret = f"{self._parent._fullname}.{self._name}"
         return ret
 
 
@@ -458,6 +463,10 @@ class Environ(VarGroup):
     def errors(self) -> List[EnviumError]:
         return self._errors
 
+    @property
+    def _fullname(self) -> str:
+        return self._name
+
 
 def var(
     default: Optional[VarType] = None,
